@@ -185,8 +185,8 @@ class RealmsServiceAsyncClient:
                 The request object. Request message for
                 RealmsService.ListRealms.
             parent (:class:`str`):
-                Required. The parent resource name. Uses the form:
-                ``projects/{project}/locations/{location}``.
+                Required. The parent resource name, in the following
+                form: ``projects/{project}/locations/{location}``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -274,8 +274,8 @@ class RealmsServiceAsyncClient:
                 The request object. Request message for
                 RealmsService.GetRealm.
             name (:class:`str`):
-                Required. The name of the realm to retrieve. Uses the
-                form:
+                Required. The name of the realm to retrieve, in the
+                following form:
                 ``projects/{project}/locations/{location}/realms/{realm}``.
 
                 This corresponds to the ``name`` field
@@ -355,8 +355,8 @@ class RealmsServiceAsyncClient:
                 The request object. Request message for
                 RealmsService.CreateRealm.
             parent (:class:`str`):
-                Required. The parent resource name. Uses the form:
-                ``projects/{project}/locations/{location}``.
+                Required. The parent resource name, in the following
+                form: ``projects/{project}/locations/{location}``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -455,8 +455,8 @@ class RealmsServiceAsyncClient:
                 The request object. Request message for
                 RealmsService.DeleteRealm.
             name (:class:`str`):
-                Required. The name of the realm to delete. Uses the
-                form:
+                Required. The name of the realm to delete, in the
+                following form:
                 ``projects/{project}/locations/{location}/realms/{realm}``.
 
                 This corresponds to the ``name`` field
@@ -558,9 +558,7 @@ class RealmsServiceAsyncClient:
             update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 Required. The update mask applies to the resource. For
                 the ``FieldMask`` definition, see
-
-                https: //developers.google.com/protocol-buffers //
-                /docs/reference/google.protobuf#fieldmask
+                https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
